# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/contact_form/contact_form/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/contact_form/contact_form/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "ContactForm\\ContactForm\\": "packages/contact_form/contact_form/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        ContactForm\ContactForm\Providers\ContactFormServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ContactForm'  => ContactForm\ContactForm\Facades\ContactForm::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=ContactForm\\ContactFormTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="ContactForm\ContactForm\Providers\ContactFormServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="ContactForm\ContactForm\Providers\ContactFormServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="ContactForm\ContactForm\Providers\ContactFormServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/contact_form/{modulename}

**User**

    http://path-to-route-folder/user/contact_form/{modulename}

**Public**

    http://path-to-route-folder/contact_forms


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/contact_form/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/contact_form/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/contact_form/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/contact_form/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/contact_form/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/contact_form/{modulename}/{slug}
    METHOD: GET